@@ -633,7 +633,7 @@ e_book_backend_vcf_load_source (EBookBackend             *backend,
 
 			/* the database didn't exist, so we create the
 			   directory then the .vcf file */
-			rv = e_util_mkdir_hier (dirname, 0777);
+			rv = g_mkdir_with_parents (dirname, 0777);
 			if (rv == -1 && errno != EEXIST) {
 				g_warning ("failed to make directory %s: %s", dirname, strerror (errno));
 				if (errno == EACCES || errno == EPERM)
