@@ -272,7 +272,7 @@ e_cal_backend_groupwise_set_attachments_from_comp (ECalComponent *comp,
 		
 		EGwItemAttachment *attach_item;
 		char *file_contents, *encoded_data;
-		int file_len;
+		guint file_len;
 		char *attach_filename_full, *filename;
 		const char *uid;
 
@@ -1749,7 +1749,7 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
 			if (tmp) {
 				start = soup_soap_parameter_get_string_value (tmp);
 				t = e_gw_connection_get_date_from_string (start);
-				itt = icaltime_from_timet_with_zone (t, 0, default_zone ? default_zone : 0);
+				itt = icaltime_from_timet_with_zone (t, 0, default_zone ? default_zone : NULL);
 				ipt.start = itt;
 			}        
 
@@ -1757,7 +1757,7 @@ e_gw_connection_get_freebusy_info (EGwConnection *cnc, GList *users, time_t star
 			if (tmp) {
 				end = soup_soap_parameter_get_string_value (tmp);
 				t = e_gw_connection_get_date_from_string (end);
-				itt = icaltime_from_timet_with_zone (t, 0, default_zone ? default_zone : 0);
+				itt = icaltime_from_timet_with_zone (t, 0, default_zone ? default_zone : NULL);
 				ipt.end = itt;
 			}
 			icalprop = icalproperty_new_freebusy (ipt);
@@ -1917,9 +1917,11 @@ add_return_value (EGwSendOptionsReturnNotify track, ESource *source, char *notif
 	g_free (value), value = NULL;
 }
 
-void
-e_cal_backend_groupwise_store_settings (EGwSendOptions *opts, ECalBackendGroupwise *cbgw)
+gboolean
+e_cal_backend_groupwise_store_settings (GwSettings *hold)
 {
+	ECalBackendGroupwise *cbgw;
+	EGwSendOptions *opts;
 	EGwSendOptionsGeneral *gopts;
 	EGwSendOptionsStatusTracking *sopts;
 	icaltimetype tt;
@@ -1930,12 +1932,14 @@ e_cal_backend_groupwise_store_settings (EGwSendOptions *opts, ECalBackendGroupwi
 	const char *uid;
 	char *value;
 
+	cbgw = hold->cbgw;
+	opts = hold->opts;
 	source = e_cal_backend_get_source (E_CAL_BACKEND (cbgw));
 	kind = e_cal_backend_get_kind (E_CAL_BACKEND (cbgw)); 
 
 	/* TODO implement send options for Notes */
 	if (kind == ICAL_VJOURNAL_COMPONENT)
-		return;
+		return FALSE;
 
 	gopts = e_gw_sendoptions_get_general_options (opts);
 	if (kind == ICAL_VEVENT_COMPONENT) {
@@ -2021,8 +2025,15 @@ e_cal_backend_groupwise_store_settings (EGwSendOptions *opts, ECalBackendGroupwi
 		add_return_value (sopts->completed, source, "return-complete"); 
 	}	
 
+	e_source_list_sync (source_list, NULL);
+
+	g_object_unref (hold->opts);
+	g_free (hold);
+
 	g_object_unref (gconf);
 	g_object_unref (source_list);
+
+	return FALSE;
 }
 
 gboolean
