@@ -23,18 +23,19 @@
 #include <config.h>
 #endif
 
+#include <errno.h>
+#include <fcntl.h>
+#include <pthread.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <pthread.h>
 #include <unistd.h>
-#include <fcntl.h>
-#include <errno.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
+#include <glib.h>
 #include <glib/gstdio.h>
 
-#include "libedataserver/e-msgport.h"
+#include <libedataserver/e-msgport.h>
 
 #include "camel-block-file.h"
 #include "camel-file-utils.h"
@@ -83,14 +84,14 @@ static int sync_block_nolock(CamelBlockFile *bs, CamelBlock *bl);
 static int
 block_file_validate_root(CamelBlockFile *bs)
 {
-	struct stat st;
 	CamelBlockRoot *br;
-	int s;
-
+	struct stat st;
+	int retval;
+	
 	br = bs->root;
-
-	s = fstat(bs->fd, &st);
-
+	
+	retval = fstat (bs->fd, &st);
+	
 	d(printf("Validate root: '%s'\n", bs->path));
 	d(printf("version: %.8s (%.8s)\n", bs->root->version, bs->version));
 	d(printf("block size: %d (%d)%s\n", br->block_size, bs->block_size,
@@ -106,12 +107,12 @@ block_file_validate_root(CamelBlockFile *bs)
 	    || br->block_size != bs->block_size
 	    || (br->free % bs->block_size) != 0
 	    || (br->last % bs->block_size) != 0
-	    || fstat(bs->fd, &st) == -1
+	    || retval == -1
 	    || st.st_size != br->last
 	    || br->free > st.st_size
 	    || (br->flags & CAMEL_BLOCK_FILE_SYNC) == 0) {
 #if 0
-		if (s != -1 && st.st_size > 0) {
+		if (retval != -1 && st.st_size > 0) {
 			g_warning("Invalid root: '%s'", bs->path);
 			g_warning("version: %.8s (%.8s)", bs->root->version, bs->version);
 			g_warning("block size: %d (%d)%s", br->block_size, bs->block_size,
@@ -218,7 +219,7 @@ camel_block_file_finalise(CamelBlockFile *bs)
 	bn = bl->next;
 	while (bn) {
 		if (bl->refcount != 0)
-			g_warning("Block '%d' still referenced", bl->id);
+			g_warning("Block '%u' still referenced", bl->id);
 		g_free(bl);
 		bl = bn;
 		bn = bn->next;
@@ -967,7 +968,7 @@ key_file_unuse(CamelKeyFile *bs)
  * camel_key_file_new:
  * @path: 
  * @flags: open flags
- * @version[]: Version string (header) of file.  Currently
+ * @version: Version string (header) of file.  Currently
  * written but not checked.
  * 
  * Create a new key file.  A linked list of record blocks.
