@@ -27,12 +27,14 @@
 #include <config.h>
 #endif
 
-#include "camel-disco-store.h"
+#include <glib.h>
+#include <glib/gi18n-lib.h>
+
 #include "camel-disco-diary.h"
 #include "camel-disco-folder.h"
+#include "camel-disco-store.h"
 #include "camel-exception.h"
 #include "camel-session.h"
-#include "camel-i18n.h"
 
 #define d(x) 
 
@@ -159,6 +161,10 @@ disco_connect (CamelService *service, CamelException *ex)
 	case CAMEL_DISCO_STORE_RESYNCING:
 		if (!CDS_CLASS (service)->connect_online (service, ex))
 			return FALSE;
+
+		if (!store->diary)
+			return TRUE;
+
 		d(printf(" diary is %s\n", camel_disco_diary_empty(store->diary)?"empty":"not empty"));
 		if (camel_disco_diary_empty (store->diary))
 			return TRUE;
@@ -292,6 +298,8 @@ static void
 set_status(CamelDiscoStore *disco_store, CamelDiscoStoreStatus status, CamelException *ex)
 {
 	CamelException x;
+	CamelService *service = CAMEL_SERVICE (disco_store);
+	gboolean network_state = camel_session_get_network_state (service->session);
 
 	if (disco_store->status == status)
 		return;
@@ -299,32 +307,36 @@ set_status(CamelDiscoStore *disco_store, CamelDiscoStoreStatus status, CamelExce
 	camel_exception_init(&x);
 	/* Sync the folder fully if we've been told to sync online for this store or this folder
 	   and we're going offline */
-	if (disco_store->status == CAMEL_DISCO_STORE_ONLINE
-	    && status == CAMEL_DISCO_STORE_OFFLINE) {
-		if (((CamelStore *)disco_store)->folders) {
-			GPtrArray *folders;
-			CamelFolder *folder;
-			int i, sync;
-			
-			sync =  camel_url_get_param(((CamelService *)disco_store)->url, "offline_sync") != NULL;
 
-			folders = camel_object_bag_list(((CamelStore *)disco_store)->folders);
-			for (i=0;i<folders->len;i++) {
-				folder = folders->pdata[i];
-				if (CAMEL_CHECK_TYPE(folder, CAMEL_DISCO_FOLDER_TYPE)
-				    && (sync || ((CamelDiscoFolder *)folder)->offline_sync)) {
-					camel_disco_folder_prepare_for_offline((CamelDiscoFolder *)folder, "(match-all)", &x);
-					camel_exception_clear(&x);
+	if (network_state) {
+		if (disco_store->status == CAMEL_DISCO_STORE_ONLINE
+		    && status == CAMEL_DISCO_STORE_OFFLINE) {
+			if (((CamelStore *)disco_store)->folders) {
+				GPtrArray *folders;
+				CamelFolder *folder;
+				int i, sync;
+				
+				sync =  camel_url_get_param(((CamelService *)disco_store)->url, "offline_sync") != NULL;
+				
+				folders = camel_object_bag_list(((CamelStore *)disco_store)->folders);
+				for (i=0;i<folders->len;i++) {
+					folder = folders->pdata[i];
+					if (CAMEL_CHECK_TYPE(folder, CAMEL_DISCO_FOLDER_TYPE)
+					    && (sync || ((CamelDiscoFolder *)folder)->offline_sync)) {
+						camel_disco_folder_prepare_for_offline((CamelDiscoFolder *)folder, "(match-all)", &x);
+						camel_exception_clear(&x);
+					}
+					camel_object_unref(folder);
 				}
-				camel_object_unref(folder);
+				g_ptr_array_free(folders, TRUE);
 			}
-			g_ptr_array_free(folders, TRUE);
 		}
+		
+		camel_store_sync(CAMEL_STORE (disco_store), FALSE, &x);
+		camel_exception_clear(&x);
 	}
-
-	camel_store_sync(CAMEL_STORE (disco_store), FALSE, &x);
-	camel_exception_clear(&x);
-	if (!camel_service_disconnect (CAMEL_SERVICE (disco_store), TRUE, ex))
+	
+	if (!camel_service_disconnect (CAMEL_SERVICE (disco_store), network_state, ex))
 		return;
 
 	disco_store->status = status;
