@@ -8,15 +8,15 @@
  * Copyright 1999-2003 Ximian, Inc. (www.ximian.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -28,20 +28,23 @@
 
 #include <string.h>
 
-#include "camel-folder.h"
-#include "camel-exception.h"
-#include "camel-store.h"
-#include "camel-mime-message.h"
-#include "camel-debug.h"
-#include "libedataserver/e-memory.h"
-#include "camel-operation.h"
-#include "camel-session.h"
-#include "camel-filter-driver.h"
-#include "camel-private.h"
-#include "camel-vtrash-folder.h"
-#include "camel-i18n.h"
+#include <glib.h>
+#include <glib/gi18n-lib.h>
 
-#define d(x) 
+#include <libedataserver/e-memory.h>
+
+#include "camel-debug.h"
+#include "camel-exception.h"
+#include "camel-filter-driver.h"
+#include "camel-folder.h"
+#include "camel-mime-message.h"
+#include "camel-operation.h"
+#include "camel-private.h"
+#include "camel-session.h"
+#include "camel-store.h"
+#include "camel-vtrash-folder.h"
+
+#define d(x)
 #define w(x)
 
 extern int camel_verbose_debug;
@@ -172,8 +175,8 @@ camel_folder_init (gpointer object, gpointer klass)
 	folder->priv = g_malloc0(sizeof(*folder->priv));
 	folder->priv->frozen = 0;
 	folder->priv->changed_frozen = camel_folder_change_info_new();
-	folder->priv->lock = e_mutex_new(E_MUTEX_REC);
-	folder->priv->change_lock = e_mutex_new(E_MUTEX_SIMPLE);
+	g_static_rec_mutex_init(&folder->priv->lock);
+	g_static_mutex_init(&folder->priv->change_lock);
 }
 
 static void
@@ -194,8 +197,8 @@ camel_folder_finalize (CamelObject *object)
 
 	camel_folder_change_info_free(p->changed_frozen);
 	
-	e_mutex_destroy(p->lock);
-	e_mutex_destroy(p->change_lock);
+	g_static_rec_mutex_free(&p->lock);
+	g_static_mutex_free(&p->change_lock);
 	
 	g_free(p);
 }
@@ -268,12 +271,12 @@ camel_folder_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 {
 	g_return_if_fail (CAMEL_IS_FOLDER (folder));
 
-	CAMEL_FOLDER_LOCK(folder, lock);
+	CAMEL_FOLDER_REC_LOCK(folder, lock);
 	
 	if (!(folder->folder_flags & CAMEL_FOLDER_HAS_BEEN_DELETED))
 		CF_CLASS (folder)->sync (folder, expunge, ex);
 	
-	CAMEL_FOLDER_UNLOCK(folder, lock);
+	CAMEL_FOLDER_REC_UNLOCK(folder, lock);
 }
 
 
@@ -530,12 +533,12 @@ camel_folder_expunge (CamelFolder *folder, CamelException *ex)
 {
 	g_return_if_fail (CAMEL_IS_FOLDER (folder));
 	
-	CAMEL_FOLDER_LOCK(folder, lock);
+	CAMEL_FOLDER_REC_LOCK(folder, lock);
 	
 	if (!(folder->folder_flags & CAMEL_FOLDER_HAS_BEEN_DELETED))
 		CF_CLASS (folder)->expunge (folder, ex);
 	
-	CAMEL_FOLDER_UNLOCK(folder, lock);
+	CAMEL_FOLDER_REC_UNLOCK(folder, lock);
 }
 
 static int
@@ -644,11 +647,11 @@ camel_folder_append_message (CamelFolder *folder, CamelMimeMessage *message,
 {
 	g_return_if_fail (CAMEL_IS_FOLDER (folder));
 
-	CAMEL_FOLDER_LOCK(folder, lock);
+	CAMEL_FOLDER_REC_LOCK(folder, lock);
 
 	CF_CLASS (folder)->append_message (folder, message, info, appended_uid, ex);
 
-	CAMEL_FOLDER_UNLOCK(folder, lock);
+	CAMEL_FOLDER_REC_UNLOCK(folder, lock);
 }
 
 
@@ -1066,11 +1069,11 @@ camel_folder_get_message (CamelFolder *folder, const char *uid, CamelException *
 
 	g_return_val_if_fail (CAMEL_IS_FOLDER (folder), NULL);
 
-	CAMEL_FOLDER_LOCK(folder, lock);
+	CAMEL_FOLDER_REC_LOCK(folder, lock);
 
 	ret = CF_CLASS (folder)->get_message (folder, uid, ex);
 
-	CAMEL_FOLDER_UNLOCK(folder, lock);
+	CAMEL_FOLDER_REC_UNLOCK(folder, lock);
 
 	if (ret && camel_debug_start(":folder")) {
 		printf("CamelFolder:get_message('%s', '%s') =\n", folder->full_name, uid);
@@ -1276,7 +1279,7 @@ static GPtrArray *
 search_by_uids(CamelFolder *folder, const char *exp, GPtrArray *uids, CamelException *ex)
 {
 	camel_exception_setv (ex, CAMEL_EXCEPTION_FOLDER_INVALID,
-			      _("Unsupported operation: search by uids: for %s"),
+			      _("Unsupported operation: search by UIDs: for %s"),
 			      camel_type_to_name (CAMEL_OBJECT_GET_TYPE (folder)));
 	
 	w(g_warning ("CamelFolder::search_by_expression not implemented for "
@@ -1475,9 +1478,9 @@ camel_folder_delete (CamelFolder *folder)
 {
 	g_return_if_fail (CAMEL_IS_FOLDER (folder));
 	
-	CAMEL_FOLDER_LOCK (folder, lock);
+	CAMEL_FOLDER_REC_LOCK (folder, lock);
 	if (folder->folder_flags & CAMEL_FOLDER_HAS_BEEN_DELETED) {
-		CAMEL_FOLDER_UNLOCK (folder, lock);
+		CAMEL_FOLDER_REC_UNLOCK (folder, lock);
 		return;
 	}
 	
@@ -1485,7 +1488,7 @@ camel_folder_delete (CamelFolder *folder)
 	
 	CF_CLASS (folder)->delete (folder);
 
-	CAMEL_FOLDER_UNLOCK (folder, lock);
+	CAMEL_FOLDER_REC_UNLOCK (folder, lock);
 
 	camel_object_trigger_event (folder, "deleted", NULL);
 }
@@ -1635,9 +1638,9 @@ struct _folder_filter_msg {
 };
 
 static void
-filter_filter(CamelSession *session, CamelSessionThreadMsg *msg)
+filter_filter(CamelSession *session, CamelSessionThreadMsg *tmsg)
 {
-	struct _folder_filter_msg *m = (struct _folder_filter_msg *)msg;
+	struct _folder_filter_msg *m = (struct _folder_filter_msg *) tmsg;
 	CamelMessageInfo *info;
 	int i, status = 0;
 	CamelURL *uri;
