@@ -8,15 +8,15 @@
  * Copyright 2000-2004 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -25,11 +25,6 @@
 #ifndef CAMEL_OBJECT_H
 #define CAMEL_OBJECT_H 1
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
-
 #include <glib.h>
 #include <stdio.h>		/* FILE */
 #include <stdlib.h>		/* size_t */
@@ -42,6 +37,8 @@ extern "C" {
 /* turn on so that camel_object_class_dump_tree() dumps object instances as well */
 #define CAMEL_OBJECT_TRACK_INSTANCES
 
+G_BEGIN_DECLS
+
 typedef struct _CamelObjectClass *CamelType;
 
 #ifdef G_DISABLE_CHECKS
@@ -307,8 +304,33 @@ type##_get_type(void)								\
 	return type##_type;							\
 }
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+/* Utility functions, not object specific, but too small to separate */
+typedef struct _CamelIteratorVTable CamelIteratorVTable;
+typedef struct _CamelIterator CamelIterator;
+
+struct _CamelIteratorVTable {
+	/* free fields, dont free base object */
+	void (*free)(void *it);
+	/* go to the next messageinfo */
+	const void *(*next)(void *it, CamelException *ex);
+	/* go back to the start */
+	void (*reset)(void *it);
+	/* *ESTIMATE* how many results are in the iterator */
+	int (*length)(void *it);
+};
+
+struct _CamelIterator {
+	CamelIteratorVTable *klass;
+
+	/* subclasses adds new fields afterwards */
+};
+
+void *camel_iterator_new(CamelIteratorVTable *klass, size_t size);
+void camel_iterator_free(void *it);
+const void *camel_iterator_next(void *it, CamelException *ex);
+void camel_iterator_reset(void *it);
+int camel_iterator_length(void *it);
+
+G_END_DECLS
 
 #endif /* CAMEL_OBJECT_H */
