@@ -28,22 +28,24 @@
 #include <config.h>
 #endif
 
+#include <errno.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
-#include <errno.h>
+
+#include <glib/gi18n-lib.h>
+
+#include "camel-debug.h"
+#include "camel-exception.h"
+#include "camel-private.h"
+#include "camel-session.h"
+#include "camel-utf8.h"
 
 #include "camel-imap-command.h"
-#include "camel-imap-utils.h"
 #include "camel-imap-folder.h"
-#include "camel-imap-store.h"
 #include "camel-imap-store-summary.h"
-#include <camel/camel-exception.h>
-#include <camel/camel-private.h>
-#include <camel/camel-utf8.h>
-#include <camel/camel-session.h>
-#include <camel/camel-i18n.h>
-#include <camel/camel-debug.h>
+#include "camel-imap-store.h"
+#include "camel-imap-utils.h"
 
 extern int camel_verbose_debug;
 
@@ -855,8 +857,6 @@ imap_command_strdup_vprintf (CamelImapStore *store, const char *fmt,
 		start = *p ? p + 1 : p;
 	}
 	
-	g_ptr_array_free (args, TRUE);
-
 	return out;
 }
 
