@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  Camel
- *  Copyright (C) 1999-2004 Jeffrey Stedfast
+ *  Copyright (C) 1999-2006 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,28 +22,29 @@
 #include <config.h>
 #endif
 
-#include <glib.h>
-
+#include <dirent.h>
+#include <errno.h>
+#include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <dirent.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <errno.h>
 #include <time.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+
+#include <glib.h>
+#include <glib/gi18n-lib.h>
 
 #include <libedataserver/e-data-server-util.h>
-#include <camel/camel-utf8.h>
-#include <camel/camel-private.h>
-#include <camel/camel-file-utils.h>
-#include <camel/camel-mime-message.h>
-#include <camel/camel-stream-mem.h>
-#include <camel/camel-stream-filter.h>
-#include <camel/camel-mime-filter-crlf.h>
-#include <camel/camel-i18n.h>
+
+#include "camel-file-utils.h"
+#include "camel-mime-filter-crlf.h"
+#include "camel-mime-message.h"
+#include "camel-private.h"
+#include "camel-stream-filter.h"
+#include "camel-stream-mem.h"
+#include "camel-utf8.h"
 
 #include "camel-imap4-utils.h"
 #include "camel-imap4-store.h"
@@ -346,7 +347,7 @@ camel_imap4_folder_new (CamelStore *store, const char *full_name, CamelException
 	
 	folder->summary = camel_imap4_summary_new (folder);
 	imap4_folder->cachedir = imap4_store_build_filename (store, folder->full_name);
-	e_util_mkdir_hier (imap4_folder->cachedir, 0777);
+	g_mkdir_with_parents (imap4_folder->cachedir, 0777);
 	
 	imap4_folder->cache = camel_data_cache_new (imap4_folder->cachedir, 0, NULL);
 	
@@ -552,7 +553,7 @@ imap4_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 	if (offline->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL)
 		return;
 	
-	CAMEL_SERVICE_LOCK (folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK (folder->parent_store, connect_lock);
 	
 	/* gather a list of changes to sync to the server */
 	if (folder->permanent_flags) {
@@ -620,7 +621,7 @@ imap4_sync (CamelFolder *folder, gboolean expunge, CamelException *ex)
 	
  done:
 	
-	CAMEL_SERVICE_UNLOCK (folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (folder->parent_store, connect_lock);
 }
 
 static void
@@ -641,7 +642,7 @@ imap4_refresh_info (CamelFolder *folder, CamelException *ex)
 	if (offline->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL)
 		return;
 	
-	CAMEL_SERVICE_LOCK (folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK (folder->parent_store, connect_lock);
 	
 	if (folder != selected) {
 		if (camel_imap4_engine_select_folder (engine, folder, ex) == -1)
@@ -666,7 +667,7 @@ imap4_refresh_info (CamelFolder *folder, CamelException *ex)
 	
  done:
 	
-	CAMEL_SERVICE_UNLOCK (folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (folder->parent_store, connect_lock);
 }
 
 static int
@@ -777,15 +778,15 @@ imap4_get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 	CamelIMAP4Command *ic;
 	int id;
 	
-	CAMEL_SERVICE_LOCK (folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK (folder->parent_store, connect_lock);
 	
 	if (imap4_folder->cache && (stream = camel_data_cache_get (imap4_folder->cache, "cache", uid, ex))) {
 		message = camel_mime_message_new ();
 		
 		if (camel_data_wrapper_construct_from_stream ((CamelDataWrapper *) message, stream) == -1) {
 			if (errno == EINTR) {
-				CAMEL_SERVICE_UNLOCK (folder->parent_store, connect_lock);
-				camel_exception_setv (ex, CAMEL_EXCEPTION_USER_CANCEL, _("User cancelled"));
+				CAMEL_SERVICE_REC_UNLOCK (folder->parent_store, connect_lock);
+				camel_exception_setv (ex, CAMEL_EXCEPTION_USER_CANCEL, _("User canceled"));
 				camel_object_unref (message);
 				camel_object_unref (stream);
 				return NULL;
@@ -801,12 +802,12 @@ imap4_get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 	}
 	
 	if (message != NULL) {
-		CAMEL_SERVICE_UNLOCK (folder->parent_store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (folder->parent_store, connect_lock);
 		return message;
 	}
 	
 	if (offline->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
-		CAMEL_SERVICE_UNLOCK (folder->parent_store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (folder->parent_store, connect_lock);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_UNAVAILABLE,
 				     _("This message is not available in offline mode."));
 		return NULL;
@@ -878,7 +879,7 @@ imap4_get_message (CamelFolder *folder, const char *uid, CamelException *ex)
 	
  done:
 	
-	CAMEL_SERVICE_UNLOCK (folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (folder->parent_store, connect_lock);
 	
 	return message;
 }
@@ -921,7 +922,7 @@ imap4_append_message (CamelFolder *folder, CamelMimeMessage *message,
 		return;
 	}
 	
-	CAMEL_SERVICE_LOCK (folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK (folder->parent_store, connect_lock);
 	
 	/* construct the option flags list */
 	if (iinfo->info.flags & folder->permanent_flags) {
@@ -983,7 +984,7 @@ imap4_append_message (CamelFolder *folder, CamelMimeMessage *message,
 	if (id == -1 || ic->status != CAMEL_IMAP4_COMMAND_COMPLETE) {
 		camel_exception_xfer (ex, &ic->ex);
 		camel_imap4_command_unref (ic);
-		CAMEL_SERVICE_UNLOCK (folder->parent_store, connect_lock);
+		CAMEL_SERVICE_REC_UNLOCK (folder->parent_store, connect_lock);
 		return;
 	}
 	
@@ -996,7 +997,7 @@ imap4_append_message (CamelFolder *folder, CamelMimeMessage *message,
 			resp = ic->resp_codes->pdata[i];
 			if (resp->code == CAMEL_IMAP4_RESP_CODE_APPENDUID) {
 				if (resp->v.appenduid.uidvalidity == summary->uidvalidity)
-					*appended_uid = g_strdup_printf ("%u", resp->v.appenduid.uid);
+					*appended_uid = g_strdup_printf ("%lu", resp->v.appenduid.uid);
 				break;
 			}
 		}
@@ -1044,7 +1045,7 @@ imap4_append_message (CamelFolder *folder, CamelMimeMessage *message,
 	
 	camel_imap4_command_unref (ic);
 	
-	CAMEL_SERVICE_UNLOCK (folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (folder->parent_store, connect_lock);
 }
 
 
@@ -1100,7 +1101,7 @@ imap4_transfer_messages_to (CamelFolder *src, GPtrArray *uids, CamelFolder *dest
 	
 	g_ptr_array_sort (infos, (GCompareFunc) info_uid_sort);
 	
-	CAMEL_SERVICE_LOCK (src->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK (src->parent_store, connect_lock);
 	
 	/* check for offline operation */
 	if (offline->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
@@ -1196,7 +1197,7 @@ imap4_transfer_messages_to (CamelFolder *src, GPtrArray *uids, CamelFolder *dest
 		camel_message_info_free (infos->pdata[i]);
 	g_ptr_array_free (infos, TRUE);
 	
-	CAMEL_SERVICE_UNLOCK (src->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK (src->parent_store, connect_lock);
 }
 
 static GPtrArray *
@@ -1205,12 +1206,12 @@ imap4_search_by_expression (CamelFolder *folder, const char *expr, CamelExceptio
 	CamelIMAP4Folder *imap4_folder = (CamelIMAP4Folder *) folder;
 	GPtrArray *matches;
 	
-	CAMEL_SERVICE_LOCK(folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK(folder->parent_store, connect_lock);
 	
 	camel_folder_search_set_folder (imap4_folder->search, folder);
 	matches = camel_folder_search_search (imap4_folder->search, expr, NULL, ex);
 	
-	CAMEL_SERVICE_UNLOCK(folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK(folder->parent_store, connect_lock);
 	
 	return matches;
 }
@@ -1224,12 +1225,12 @@ imap4_search_by_uids (CamelFolder *folder, const char *expr, GPtrArray *uids, Ca
 	if (uids->len == 0)
 		return g_ptr_array_new ();
 	
-	CAMEL_SERVICE_LOCK(folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK(folder->parent_store, connect_lock);
 	
 	camel_folder_search_set_folder (imap4_folder->search, folder);
 	matches = camel_folder_search_search (imap4_folder->search, expr, uids, ex);
 	
-	CAMEL_SERVICE_UNLOCK(folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK(folder->parent_store, connect_lock);
 	
 	return matches;
 }
@@ -1241,9 +1242,9 @@ imap4_search_free (CamelFolder *folder, GPtrArray *uids)
 	
 	g_return_if_fail (imap4_folder->search);
 	
-	CAMEL_SERVICE_LOCK(folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_LOCK(folder->parent_store, connect_lock);
 	
 	camel_folder_search_free_result (imap4_folder->search, uids);
 	
-	CAMEL_SERVICE_UNLOCK(folder->parent_store, connect_lock);
+	CAMEL_SERVICE_REC_UNLOCK(folder->parent_store, connect_lock);
 }
