@@ -26,19 +26,17 @@
 #include <config.h>
 #endif
 
-#include <string.h>
 #include <ctype.h>
+#include <string.h>
 
-#include <camel/camel-offline-store.h>
+#include "camel-offline-store.h"
 
 #include "camel-imap4-command.h"
 #include "camel-imap4-engine.h"
+#include "camel-imap4-search.h"
 #include "camel-imap4-stream.h"
 #include "camel-imap4-utils.h"
 
-#include "camel-imap4-search.h"
-
-
 static void camel_imap4_search_class_init (CamelIMAP4SearchClass *klass);
 static void camel_imap4_search_init (CamelIMAP4Search *search, CamelIMAP4SearchClass *klass);
 static void camel_imap4_search_finalize (CamelObject *object);
@@ -122,7 +120,7 @@ untagged_search (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guint32 index,
 		if (token->token != CAMEL_IMAP4_TOKEN_NUMBER || token->v.number == 0)
 			goto unexpected;
 		
-		sprintf (uid, "%u", token->v.number);
+		sprintf (uid, "%lu", token->v.number);
 		if ((info = camel_folder_summary_uid (summary, uid))) {
 			g_ptr_array_add (matches, (char *) camel_message_info_uid (info));
 			camel_message_info_free (info);
