@@ -22,21 +22,21 @@
 #include <config.h>
 #endif
 
-#include <stdio.h>
-#include <string.h>
 #include <ctype.h>
 #include <errno.h>
+#include <stdio.h>
+#include <string.h>
 
-#include <camel/camel-store.h>
-#include <camel/camel-i18n.h>
-#include <camel/camel-net-utils.h>
+#include <glib/gi18n-lib.h>
+
+#include "camel-net-utils.h"
+#include "camel-store.h"
 
-#include "camel-imap4-engine.h"
-#include "camel-imap4-stream.h"
 #include "camel-imap4-command.h"
-#include "camel-imap4-summary.h"
+#include "camel-imap4-engine.h"
 #include "camel-imap4-store-summary.h"
-
+#include "camel-imap4-stream.h"
+#include "camel-imap4-summary.h"
 #include "camel-imap4-utils.h"
 
 #define d(x)
@@ -296,7 +296,7 @@ uidset_add (struct _uidset *uidset, CamelMessageInfo *info)
 		return -1;
 	}
 	
-	d(fprintf (stderr, "added uid %s to uidset (summary index = %u)\n", iuid, index));
+	d(fprintf (stderr, "added uid %s to uidset (summary index = %lu)\n", iuid, index));
 	
 	if (uidset->setlen < uidset->maxlen)
 		return 0;
@@ -382,10 +382,10 @@ camel_imap4_utils_set_unexpected_token_error (CamelException *ex, CamelIMAP4Engi
 		g_string_append (errmsg, token->v.qstring);
 		break;
 	case CAMEL_IMAP4_TOKEN_LITERAL:
-		g_string_append_printf (errmsg, "{%u}", (unsigned int)token->v.literal);
+		g_string_append_printf (errmsg, "{%lu}", token->v.literal);
 		break;
 	case CAMEL_IMAP4_TOKEN_NUMBER:
-		g_string_append_printf (errmsg, "%u", token->v.number);
+		g_string_append_printf (errmsg, "%lu", token->v.number);
 		break;
 	case CAMEL_IMAP4_TOKEN_NO_DATA:
 		g_string_append (errmsg, _("No data"));
