@@ -27,11 +27,12 @@
 #include <config.h>
 #endif
 
+#include <glib/gi18n-lib.h>
+
 #include "camel/camel-provider.h"
+#include "camel/camel-sasl.h"
 #include "camel/camel-session.h"
 #include "camel/camel-url.h"
-#include "camel/camel-sasl.h"
-#include "camel/camel-i18n.h"
 
 #include "camel-imapp-store.h"
 
